@@ -4,7 +4,7 @@ describe command('puppet apply --detailed-exitcodes --execute "include mysql::cl
   its(:exit_status) { should eq 2 }
 end
 
-describe package('mysql-client') do
+describe package('mariadb-client') do
   it { should be_installed }
 end
 
@@ -12,7 +12,7 @@ describe command('puppet apply --detailed-exitcodes --execute "include mysql::se
   its(:exit_status) { should eq 2 }
 end
 
-describe package('mysql-server') do
+describe package('mariadb-server') do
   it { should be_installed }
 end
 
